# Changelog

All notable changes to this project will be documented in this file.

## [0.2.4] - 2025-02-09

### 🚀 Features

- Add option path for next version inference (#112)

<!-- generated by git-cliff -->
